@@ -1,13 +1,15 @@
 """Module containing all required information about the interface between raw (or transformed)
 public data and DiCE explainers."""
 
-import pandas as pd
-import numpy as np
 import logging
 from collections import defaultdict
 
+import numpy as np
+import pandas as pd
+
 from dice_ml.data_interfaces.base_data_interface import _BaseData
-from dice_ml.utils.exception import SystemException, UserConfigValidationException
+from dice_ml.utils.exception import (SystemException,
+                                     UserConfigValidationException)
 
 
 class PublicData(_BaseData):
@@ -47,21 +49,10 @@ class PublicData(_BaseData):
             name) for name in self.categorical_feature_names if name in self.data_df]
 
         self._validate_and_set_continuous_features_precision(params=params)
-
-        if len(self.categorical_feature_names) > 0:
-            for feature in self.categorical_feature_names:
-                self.data_df[feature] = self.data_df[feature].apply(str)
-            self.data_df[self.categorical_feature_names] = self.data_df[self.categorical_feature_names].astype(
-                'category')
-
-        if len(self.continuous_feature_names) > 0:
-            for feature in self.continuous_feature_names:
-                if self.get_data_type(feature) == 'float':
-                    self.data_df[feature] = self.data_df[feature].astype(
-                        np.float32)
-                else:
-                    self.data_df[feature] = self.data_df[feature].astype(
-                        np.int32)
+        self.data_df = self._set_feature_dtypes(
+                self.data_df,
+                self.categorical_feature_names,
+                self.continuous_feature_names)
 
         # should move the below snippet to gradient based dice interfaces
         # self.one_hot_encoded_data = self.one_hot_encode_data(self.data_df)
@@ -147,6 +138,25 @@ class PublicData(_BaseData):
                     )
         self.permitted_range, _ = self.get_features_range(input_permitted_range)
 
+    def _set_feature_dtypes(self, data_df, categorical_feature_names,
+                            continuous_feature_names):
+        """Set the correct type of each feature column."""
+        if len(categorical_feature_names) > 0:
+            for feature in categorical_feature_names:
+                data_df[feature] = data_df[feature].apply(str)
+            data_df[categorical_feature_names] = data_df[categorical_feature_names].astype(
+                'category')
+
+        if len(continuous_feature_names) > 0:
+            for feature in continuous_feature_names:
+                if self.get_data_type(feature) == 'float':
+                    data_df[feature] = data_df[feature].astype(
+                        np.float32)
+                else:
+                    data_df[feature] = data_df[feature].astype(
+                        np.int32)
+        return data_df
+
     def check_features_to_vary(self, features_to_vary):
         if features_to_vary is not None and features_to_vary != 'all':
             not_training_features = set(features_to_vary) - set(self.feature_names)
@@ -258,7 +268,7 @@ class PublicData(_BaseData):
         """
         feature_range = {}
 
-        for idx, feature_name in enumerate(self.feature_names):
+        for _, feature_name in enumerate(self.feature_names):
             feature_range[feature_name] = []
             if feature_name in self.continuous_feature_names:
                 max_value = self.data_df[feature_name].max()
@@ -544,6 +554,10 @@ class PublicData(_BaseData):
             raise ValueError("Query instance should be a dict, a pandas dataframe, a list, or a list of dicts")
 
         test = test.reset_index(drop=True)
+        # encode categorical and numerical columns
+        test = self._set_feature_dtypes(test,
+                                        self.categorical_feature_names,
+                                        self.continuous_feature_names)
         return test
 
         # TODO: create a new method, get_LE_min_max_normalized_data() to get label-encoded and normalized data. Keep this
