@@ -2,16 +2,17 @@
 Module to generate diverse counterfactual explanations based on genetic algorithm
 This code is similar to 'GeCo: Quality Counterfactual Explanations in Real Time': https://arxiv.org/pdf/2101.01292.pdf
 """
-from dice_ml.explainer_interfaces.explainer_base import ExplainerBase
-import numpy as np
-import pandas as pd
+import copy
 import random
 import timeit
-import copy
+
+import numpy as np
+import pandas as pd
 from sklearn.preprocessing import LabelEncoder
 
 from dice_ml import diverse_counterfactuals as exp
 from dice_ml.constants import ModelTypes
+from dice_ml.explainer_interfaces.explainer_base import ExplainerBase
 
 
 class DiceGenetic(ExplainerBase):
@@ -267,7 +268,10 @@ class DiceGenetic(ExplainerBase):
 
         # Prepares user defined query_instance for DiCE.
         query_instance_orig = query_instance
-        query_instance = self.data_interface.prepare_query_instance(query_instance=query_instance)
+        query_instance_orig = self.data_interface.prepare_query_instance(
+                query_instance=query_instance_orig)
+        query_instance = self.data_interface.prepare_query_instance(
+                query_instance=query_instance)
         query_instance = self.label_encode(query_instance)
         query_instance = np.array(query_instance.values[0])
         self.x1 = query_instance
@@ -559,7 +563,7 @@ class DiceGenetic(ExplainerBase):
             if ret_df is None:
                 ret_df = df
             else:
-                ret_df = ret_df.append(df)
+                ret_df = pd.concat([ret_df, df])
         return ret_df
 
     def get_valid_feature_range(self, normalized=False):
