@@ -3,14 +3,15 @@
 Module to generate diverse counterfactual explanations based on random sampling.
 A simple implementation.
 """
-from dice_ml.explainer_interfaces.explainer_base import ExplainerBase
-import numpy as np
-import pandas as pd
 import random
 import timeit
 
+import numpy as np
+import pandas as pd
+
 from dice_ml import diverse_counterfactuals as exp
 from dice_ml.constants import ModelTypes
+from dice_ml.explainer_interfaces.explainer_base import ExplainerBase
 
 
 class DiceRandom(ExplainerBase):
@@ -121,7 +122,7 @@ class DiceRandom(ExplainerBase):
                 if cfs_df is None:
                     cfs_df = rows_to_add.copy()
                 else:
-                    cfs_df = cfs_df.append(rows_to_add)
+                    cfs_df = pd.concat([cfs_df, rows_to_add])
                 cfs_df.drop_duplicates(inplace=True)
                 # Always change at least 2 features before stopping
                 if num_features_to_vary >= 2 and len(cfs_df) >= total_CFs:
