@@ -2,16 +2,18 @@
    Subclasses implement interfaces for different ML frameworks such as TensorFlow or PyTorch.
    All methods are in dice_ml.explainer_interfaces"""
 
+import pickle
 from abc import ABC, abstractmethod
+from collections.abc import Iterable
+
 import numpy as np
 import pandas as pd
+from sklearn.neighbors import KDTree
 from tqdm import tqdm
 
-from collections.abc import Iterable
-from sklearn.neighbors import KDTree
+from dice_ml.constants import ModelTypes, _PostHocSparsityTypes
 from dice_ml.counterfactual_explanations import CounterfactualExplanations
 from dice_ml.utils.exception import UserConfigValidationException
-from dice_ml.constants import ModelTypes
 
 
 class ExplainerBase(ABC):
@@ -45,10 +47,59 @@ class ExplainerBase(ABC):
         # self.cont_precisions = \
         #   [self.data_interface.get_decimal_precisions()[ix] for ix in self.encoded_continuous_feature_indexes]
 
+    def _validate_counterfactual_configuration(
+            self, query_instances, total_CFs,
+            desired_class="opposite", desired_range=None,
+            permitted_range=None, features_to_vary="all",
+            stopping_threshold=0.5, posthoc_sparsity_param=0.1,
+            posthoc_sparsity_algorithm="linear", verbose=False, **kwargs):
+
+        if total_CFs <= 0:
+            raise UserConfigValidationException(
+                "The number of counterfactuals generated per query instance (total_CFs) should be a positive integer.")
+
+        if features_to_vary != "all":
+            if len(features_to_vary) == 0:
+                raise UserConfigValidationException("Some features need to be varied for generating counterfactuals.")
+
+        if posthoc_sparsity_algorithm not in _PostHocSparsityTypes.ALL:
+            raise UserConfigValidationException(
+                'The posthoc_sparsity_algorithm should be {0} and not {1}'.format(
+                    ' or '.join(_PostHocSparsityTypes.ALL), posthoc_sparsity_algorithm)
+                )
+
+        if stopping_threshold < 0.0 or stopping_threshold > 1.0:
+            raise UserConfigValidationException('The stopping_threshold should lie between {0} and {1}'.format(
+                str(0.0), str(1.0)))
+
+        if posthoc_sparsity_param is not None and (posthoc_sparsity_param < 0.0 or posthoc_sparsity_param > 1.0):
+            raise UserConfigValidationException('The posthoc_sparsity_param should lie between {0} and {1}'.format(
+                str(0.0), str(1.0)))
+
+        if self.model is not None and self.model.model_type == ModelTypes.Classifier:
+            if desired_range is not None:
+                raise UserConfigValidationException(
+                    'The desired_range parameter should not be set for classification task')
+
+        if self.model is not None and self.model.model_type == ModelTypes.Regressor:
+            if desired_range is None:
+                raise UserConfigValidationException(
+                    'The desired_range parameter should be set for regression task')
+
+        if desired_range is not None:
+            if len(desired_range) != 2:
+                raise UserConfigValidationException(
+                    "The parameter desired_range needs to have two numbers in ascending order.")
+            if desired_range[0] > desired_range[1]:
+                raise UserConfigValidationException(
+                    "The range provided in desired_range should be in ascending order.")
+
     def generate_counterfactuals(self, query_instances, total_CFs,
                                  desired_class="opposite", desired_range=None,
                                  permitted_range=None, features_to_vary="all",
                                  stopping_threshold=0.5, posthoc_sparsity_param=0.1,
+                                 proximity_weight=0.2, sparsity_weight=0.2, diversity_weight=5.0,
+                                 categorical_penalty=0.1,
                                  posthoc_sparsity_algorithm="linear", verbose=False, **kwargs):
         """General method for generating counterfactuals.
 
@@ -58,12 +109,22 @@ class ExplainerBase(ABC):
         :param desired_class: Desired counterfactual class - can take 0 or 1. Default value
                               is "opposite" to the outcome class of query_instance for binary classification.
         :param desired_range: For regression problems. Contains the outcome range to
-                              generate counterfactuals in.
+                              generate counterfactuals in. This should be a list of two numbers in
+                              ascending order.
         :param permitted_range: Dictionary with feature names as keys and permitted range in list as values.
                                 Defaults to the range inferred from training data.
                                 If None, uses the parameters initialized in data_interface.
         :param features_to_vary: Either a string "all" or a list of feature names to vary.
         :param stopping_threshold: Minimum threshold for counterfactuals target class probability.
+        :param proximity_weight: A positive float. Larger this weight, more close the counterfactuals are to the
+                                 query_instance. Used by ['genetic', 'gradientdescent'],
+                                 ignored by ['random', 'kdtree'] methods.
+        :param sparsity_weight: A positive float. Larger this weight, less features are changed from the query_instance.
+                                Used by ['genetic', 'kdtree'], ignored by ['random', 'gradientdescent'] methods.
+        :param diversity_weight: A positive float. Larger this weight, more diverse the counterfactuals are.
+                                 Used by ['genetic', 'gradientdescent'], ignored by ['random', 'kdtree'] methods.
+        :param categorical_penalty: A positive float. A weight to ensure that all levels of a categorical variable sums to 1.
+                                 Used by ['genetic', 'gradientdescent'], ignored by ['random', 'kdtree'] methods.
         :param posthoc_sparsity_param: Parameter for the post-hoc operation on continuous features to enhance sparsity.
         :param posthoc_sparsity_algorithm: Perform either linear or binary search. Takes "linear" or "binary".
                                            Prefer binary search when a feature range is large (for instance,
@@ -77,9 +138,17 @@ class ExplainerBase(ABC):
         :returns: A CounterfactualExplanations object that contains the list of
                   counterfactual examples per query_instance as one of its attributes.
         """
-        if total_CFs <= 0:
-            raise UserConfigValidationException(
-                "The number of counterfactuals generated per query instance (total_CFs) should be a positive integer.")
+        self._validate_counterfactual_configuration(
+            query_instances=query_instances,
+            total_CFs=total_CFs,
+            desired_class=desired_class,
+            desired_range=desired_range,
+            permitted_range=permitted_range, features_to_vary=features_to_vary,
+            stopping_threshold=stopping_threshold, posthoc_sparsity_param=posthoc_sparsity_param,
+            posthoc_sparsity_algorithm=posthoc_sparsity_algorithm, verbose=verbose,
+            kwargs=kwargs
+        )
+
         cf_examples_arr = []
         query_instances_list = []
         if isinstance(query_instances, pd.DataFrame):
@@ -87,6 +156,7 @@ class ExplainerBase(ABC):
                 query_instances_list.append(query_instances[ix:(ix+1)])
         elif isinstance(query_instances, Iterable):
             query_instances_list = query_instances
+
         for query_instance in tqdm(query_instances_list):
             self.data_interface.set_continuous_feature_indexes(query_instance)
             res = self._generate_counterfactuals(
@@ -101,6 +171,9 @@ class ExplainerBase(ABC):
                 verbose=verbose,
                 **kwargs)
             cf_examples_arr.append(res)
+
+        self._check_any_counterfactuals_computed(cf_examples_arr=cf_examples_arr)
+
         return CounterfactualExplanations(cf_examples_list=cf_examples_arr)
 
     @abstractmethod
@@ -202,14 +275,26 @@ class ExplainerBase(ABC):
                   the list of counterfactuals per input, local feature importances per
                   input, and the global feature importance summarized over all inputs.
         """
+        self._validate_counterfactual_configuration(
+            query_instances=query_instances,
+            total_CFs=total_CFs,
+            desired_class=desired_class,
+            desired_range=desired_range,
+            permitted_range=permitted_range, features_to_vary=features_to_vary,
+            stopping_threshold=stopping_threshold, posthoc_sparsity_param=posthoc_sparsity_param,
+            posthoc_sparsity_algorithm=posthoc_sparsity_algorithm,
+            kwargs=kwargs
+        )
         if cf_examples_list is not None:
             if any([len(cf_examples.final_cfs_df) < 10 for cf_examples in cf_examples_list]):
                 raise UserConfigValidationException(
                     "The number of counterfactuals generated per query instance should be "
-                    "greater than or equal to 10")
+                    "greater than or equal to 10 to compute feature importance for all query points")
         elif total_CFs < 10:
-            raise UserConfigValidationException("The number of counterfactuals generated per "
-                                                "query instance should be greater than or equal to 10")
+            raise UserConfigValidationException(
+                "The number of counterfactuals requested per "
+                "query instance should be greater than or equal to 10 "
+                "to compute feature importance for all query points")
         importances = self.feature_importance(
             query_instances,
             cf_examples_list=cf_examples_list,
@@ -249,17 +334,36 @@ class ExplainerBase(ABC):
                   the list of counterfactuals per input, local feature importances per
                   input, and the global feature importance summarized over all inputs.
         """
+        self._validate_counterfactual_configuration(
+            query_instances=query_instances,
+            total_CFs=total_CFs,
+            desired_class=desired_class,
+            desired_range=desired_range,
+            permitted_range=permitted_range, features_to_vary=features_to_vary,
+            stopping_threshold=stopping_threshold, posthoc_sparsity_param=posthoc_sparsity_param,
+            posthoc_sparsity_algorithm=posthoc_sparsity_algorithm,
+            kwargs=kwargs
+        )
         if query_instances is not None and len(query_instances) < 10:
-            raise UserConfigValidationException("The number of query instances should be greater than or equal to 10")
+            raise UserConfigValidationException(
+                "The number of query instances should be greater than or equal to 10 "
+                "to compute global feature importance over all query points")
         if cf_examples_list is not None:
-            if any([len(cf_examples.final_cfs_df) < 10 for cf_examples in cf_examples_list]):
+            if len(cf_examples_list) < 10:
+                raise UserConfigValidationException(
+                    "The number of points for which counterfactuals generated should be "
+                    "greater than or equal to 10 "
+                    "to compute global feature importance")
+            elif any([len(cf_examples.final_cfs_df) < 10 for cf_examples in cf_examples_list]):
                 raise UserConfigValidationException(
                     "The number of counterfactuals generated per query instance should be "
-                    "greater than or equal to 10")
+                    "greater than or equal to 10 "
+                    "to compute global feature importance over all query points")
         elif total_CFs < 10:
             raise UserConfigValidationException(
-                "The number of counterfactuals generated per query instance should be greater "
-                "than or equal to 10")
+                "The number of counterfactuals requested per query instance should be greater "
+                "than or equal to 10 "
+                "to compute global feature importance over all query points")
         importances = self.feature_importance(
             query_instances,
             cf_examples_list=cf_examples_list,
@@ -296,6 +400,16 @@ class ExplainerBase(ABC):
                   the list of counterfactuals per input, local feature importances per
                   input, and the global feature importance summarized over all inputs.
         """
+        self._validate_counterfactual_configuration(
+            query_instances=query_instances,
+            total_CFs=total_CFs,
+            desired_class=desired_class,
+            desired_range=desired_range,
+            permitted_range=permitted_range, features_to_vary=features_to_vary,
+            stopping_threshold=stopping_threshold, posthoc_sparsity_param=posthoc_sparsity_param,
+            posthoc_sparsity_algorithm=posthoc_sparsity_algorithm,
+            kwargs=kwargs
+        )
         if cf_examples_list is None:
             cf_examples_list = self.generate_counterfactuals(
                 query_instances, total_CFs,
@@ -338,7 +452,7 @@ class ExplainerBase(ABC):
                 continue
 
             per_query_point_cfs = 0
-            for index, row in df.iterrows():
+            for _, row in df.iterrows():
                 per_query_point_cfs += 1
                 for col in self.data_interface.continuous_feature_names:
                     if not np.isclose(org_instance[col].iat[0], row[col]):
@@ -519,7 +633,7 @@ class ExplainerBase(ABC):
             self.target_cf_class = np.array(
                 [[self.infer_target_cfs_class(desired_class, test_pred, self.num_output_nodes)]],
                 dtype=np.float32)
-            desired_class = self.target_cf_class[0][0]
+            desired_class = int(self.target_cf_class[0][0])
             if self.target_cf_class == 0 and self.stopping_threshold > 0.5:
                 self.stopping_threshold = 0.25
             elif self.target_cf_class == 1 and self.stopping_threshold < 0.5:
@@ -684,3 +798,29 @@ class ExplainerBase(ABC):
             self.final_cfs_df[feature] = self.final_cfs_df[feature].astype(float).round(precisions[ix])
             if self.final_cfs_df_sparse is not None:
                 self.final_cfs_df_sparse[feature] = self.final_cfs_df_sparse[feature].astype(float).round(precisions[ix])
+
+    def _check_any_counterfactuals_computed(self, cf_examples_arr):
+        """Check if any counterfactuals were generated for any query point."""
+        no_cf_generated = True
+        # Check if any counterfactuals were generated for any query point
+        for cf_examples in cf_examples_arr:
+            if cf_examples.final_cfs_df is not None and len(cf_examples.final_cfs_df) > 0:
+                no_cf_generated = False
+                break
+        if no_cf_generated:
+            raise UserConfigValidationException(
+                "No counterfactuals found for any of the query points! Kindly check your configuration.")
+
+    def serialize_explainer(self, path):
+        """Serialize the explainer to the file specified by path."""
+        with open(path, "wb") as pickle_file:
+            pickle.dump(self, pickle_file)
+
+    @staticmethod
+    def deserialize_explainer(path):
+        """Reload the explainer into the memory by reading the file specified by path."""
+        deserialized_exp = None
+        with open(path, "rb") as pickle_file:
+            deserialized_exp = pickle.load(pickle_file)
+
+        return deserialized_exp
