@@ -1,17 +1,16 @@
 """
 This module containts helper functions to load data and get meta deta.
 """
+import os
+import shutil
+
 import numpy as np
 import pandas as pd
-import shutil
-import os
+from sklearn.model_selection import train_test_split
+from sklearn.preprocessing import FunctionTransformer
 
 import dice_ml
 
-# for data transformations
-from sklearn.preprocessing import FunctionTransformer
-from sklearn.model_selection import train_test_split
-
 
 def load_adult_income_dataset(only_train=True):
     """Loads adult income dataset from https://archive.ics.uci.edu/ml/datasets/Adult and prepares
@@ -129,6 +128,13 @@ def get_custom_dataset_modelpath_pipeline():
     return modelpath
 
 
+def get_custom_vars_dataset_modelpath_pipeline():
+    pkg_path = dice_ml.__path__[0]
+    model_ext = '.sav'
+    modelpath = os.path.join(pkg_path, 'utils', 'sample_trained_models', 'custom_vars'+model_ext)
+    return modelpath
+
+
 def get_custom_dataset_modelpath_pipeline_binary():
     pkg_path = dice_ml.__path__[0]
     model_ext = '.sav'
@@ -168,11 +174,10 @@ def get_base_gen_cf_initialization(data_interface, encoded_size, cont_minx, cont
                                    wm1, wm2, wm3, learning_rate):
     # Dice Imports - TODO: keep this method for VAE as a spearate module or move it to feasible_base_vae.py.
     #                      Check dependencies.
-    from dice_ml.utils.sample_architecture.vae_model import CF_VAE
-
-    # Pytorch
     from torch import optim
 
+    from dice_ml.utils.sample_architecture.vae_model import CF_VAE
+
     # Dataset for training Variational Encoder Decoder model for CF Generation
     df = data_interface.normalize_data(data_interface.one_hot_encoded_data)
     encoded_data = df[data_interface.ohe_encoded_feature_names + [data_interface.outcome_name]]
