@@ -12,17 +12,18 @@
 #
 import os
 import sys
+
 sys.path.insert(0, os.path.abspath("../../"))
 
 
 # -- Project information -----------------------------------------------------
 
 project = 'DiCE'
-copyright = '2020, Ramaravind, Amit, Chenhao'
+copyright = '2020, Ramaravind, Amit, Chenhao'  # noqa: A001
 author = 'Ramaravind, Amit, Chenhao'
 
 # The full version, including alpha/beta/rc tags
-release = '0.7.1'
+release = '0.8'
 
 
 # -- General configuration ---------------------------------------------------
