@@ -1,10 +1,11 @@
-import pytest
 from collections import OrderedDict
 
+import pytest
+
 import dice_ml
 
 
-@pytest.fixture
+@pytest.fixture()
 def data_object():
     features_dict = OrderedDict(
         [('age', [17, 90]),
