@@ -2,14 +2,13 @@ import numpy as np
 import pytest
 
 import dice_ml
-from dice_ml.utils import helpers
 from dice_ml.counterfactual_explanations import CounterfactualExplanations
-
+from dice_ml.utils import helpers
 
 torch = pytest.importorskip("torch")
 
 
-@pytest.fixture
+@pytest.fixture()
 def pyt_exp_object():
     backend = 'PYT'
     dataset = helpers.load_adult_income_dataset()
@@ -41,7 +40,7 @@ class TestDiceTorchMethods:
         weights = np.random.rand(len(self.exp.data_interface.ohe_encoded_feature_names))
         self.exp.feature_weights_list = torch.tensor(weights)
 
-    @pytest.mark.parametrize("yloss, output", [("hinge_loss", 10.8443), ("l2_loss", 0.9999), ("log_loss", 9.8443)])
+    @pytest.mark.parametrize(("yloss", "output"), [("hinge_loss", 10.8443), ("l2_loss", 0.9999), ("log_loss", 9.8443)])
     def test_yloss(self, yloss, output):
         self.exp.yloss_type = yloss
         loss1 = self.exp.compute_yloss()
@@ -53,7 +52,7 @@ class TestDiceTorchMethods:
         # proximity loss computed for given query instance and feature weights.
         assert pytest.approx(loss2.data.detach().numpy(), abs=1e-4) == 0.0068
 
-    @pytest.mark.parametrize("diversity_loss, output", [("dpp_style:inverse_dist", 0.0104), ("avg_dist", 0.1743)])
+    @pytest.mark.parametrize(("diversity_loss", "output"), [("dpp_style:inverse_dist", 0.0104), ("avg_dist", 0.1743)])
     def test_diversity_loss(self, diversity_loss, output):
         self.exp.diversity_loss_type = diversity_loss
         loss3 = self.exp.compute_diversity_loss()
